/**
 * Module for working with measurment units.
 */
/**
 * Represents a measurement unit.
 * @see https://developers.arcgis.com/javascript/jsapi/bufferparameters-amd.html#unit
 */
export interface IUnit {
    name: string;
    value: number;
    description: string;
}
/**
 * Array of possible measurement units.
 */
export declare const units: IUnit[];
/**
 * Creates an <option> corresponding to a measurement unit.
 * @param unit measurement unit info
 * @example
 * const option = unitToOption({ name: "StatuteMile", value: 9093, description: "Statute Mile" });
 * // Returns <option value='9093' data-name='StatuteMile'>Statute Mile</option>
 */
export declare function unitToOption(unit: IUnit): HTMLOptionElement;
/**
 * Creates the contents of a unit <select>.
 * @param {string} [defaultName] - The name of the measurment unit that will be set as the default.
 * @returns {DocumentFragment} - Document fragment containing options and optgroups to be added to a select element.
 */
export declare function createUnitSelectContents(defaultName: string): DocumentFragment;
/**
 * Creates a select element for selecting a measurement unit.
 * @param defaultName The name of the unit that will be the default selected option.
 */
export declare function createUnitSelect(defaultName: string): HTMLSelectElement;
/**
 * Returns the unit that matches the given unit ID.
 * @returns {Unit}
 */
export declare function getUnitForId(unitId: number | string): IUnit;
